@@ -705,6 +705,14 @@ pcp_process_info(int pid, int *array_size)
 			}
 			else if (strcmp(buf, "ProcessInfo") == 0)
 			{
+				if(process_info == NULL)
+				{
+					if (debug) fprintf(stderr, "DEBUG: invalid data.\"%s\"\n", buf);
+					free(buf);
+					errorcode = UNKNOWNERR;
+					return NULL;
+				}
+
 				index = (char *) memchr(buf, '\0', rsize) + 1;
 				if (index != NULL)
 					strcpy(process_info->connection_info[offset].database, index);
@@ -792,11 +800,22 @@ pcp_systemdb_info(void)
 	}
 	if (debug) fprintf(stderr, "DEBUG: send: tos=\"S\", len=%d\n", ntohl(wsize));
 
-	while (1) {
+	while (1)
+	{
 		if (pcp_read(pc, &tos, 1))
+		{
+			if (buf != NULL)
+				free(buf);
 			return NULL;
+		}
+
 		if (pcp_read(pc, &rsize, sizeof(int)))
+		{
+			if (buf != NULL)
+				free(buf);
 			return NULL;
+		}
+
 		rsize = ntohl(rsize);
 		buf = (char *)malloc(rsize);
 		if (buf == NULL)
